import { replication } from '@powersync/service-core';
import { WalStreamReplicationJob } from './WalStreamReplicationJob.js';
import { cleanUpReplicationSlot } from './replication-utils.js';
export class WalStreamReplicator extends replication.AbstractReplicator {
    constructor(options) {
        super(options);
        this.connectionFactory = options.connectionFactory;
    }
    createJob(options) {
        return new WalStreamReplicationJob({
            id: this.createJobId(options.storage.group_id),
            storage: options.storage,
            connectionFactory: this.connectionFactory,
            lock: options.lock,
            rateLimiter: this.rateLimiter
        });
    }
    async cleanUp(syncRulesStorage) {
        const connectionManager = this.connectionFactory.create({
            idleTimeout: 30000,
            maxSize: 1
        });
        try {
            // TODO: Slot_name will likely have to come from a different source in the future
            await cleanUpReplicationSlot(syncRulesStorage.slot_name, connectionManager.pool);
        }
        finally {
            await connectionManager.end();
        }
    }
    async stop() {
        await super.stop();
        await this.connectionFactory.shutdown();
    }
}
//# sourceMappingURL=WalStreamReplicator.js.map