import { Worker } from 'node:worker_threads';
export async function populateData(options) {
    const WORKER_TIMEOUT = 30000;
    const worker = new Worker(new URL('./populate_test_data_worker.js', import.meta.url), {
        workerData: options
    });
    const timeout = setTimeout(() => {
        // Exits with code 1 below
        worker.terminate();
    }, WORKER_TIMEOUT);
    try {
        return await new Promise((resolve, reject) => {
            worker.on('message', resolve);
            worker.on('error', reject);
            worker.on('exit', (code) => {
                if (code !== 0) {
                    reject(new Error(`Populating data failed with exit code ${code}`));
                }
            });
        });
    }
    finally {
        clearTimeout(timeout);
    }
}
//# sourceMappingURL=populate_test_data.js.map